/*************************************************************
 *
 *  MathJax/jax/output/HTML-CSS/fonts/TeX/AMS/Regular/GeometricShapes.js
 *
 *  Copyright (c) 2009-2012 Design Science, Inc.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

MathJax.Hub.Insert(
  MathJax.OutputJax['HTML-CSS'].FONTDATA.FONTS['MathJax_AMS'],
  {
    0x25A0: [689,0,778,55,722],        // BLACK SQUARE
    0x25A1: [689,0,778,55,722],        // WHITE SQUARE
    0x25B2: [575,20,722,84,637],       // BLACK UP-POINTING TRIANGLE
    0x25B3: [575,20,722,84,637],       // WHITE UP-POINTING TRIANGLE
    0x25B6: [539,41,778,83,694],       // BLACK RIGHT-POINTING TRIANGLE
    0x25BC: [576,19,722,84,637],       // BLACK DOWN-POINTING TRIANGLE
    0x25BD: [576,19,722,84,637],       // WHITE DOWN-POINTING TRIANGLE
    0x25C0: [539,41,778,83,694],       // BLACK LEFT-POINTING TRIANGLE
    0x25CA: [716,132,667,56,611]       // LOZENGE
  }
);

MathJax.Ajax.loadComplete(MathJax.OutputJax["HTML-CSS"].fontDir + "/AMS/Regular/GeometricShapes.js");
